##  Use the Portal Feature
![Portal interface showing application search, filters, and references for IT management.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio8f797845395e42e0a9d1e53df1c13a96_HiRes.png)
Portal elements:
  1. Portal Name: This is the name as configured by the admin.
  2. Search: On an Applications portal for example, users can look up Applications available in the Inventory.
  3. Links: Configurable by an Admin, here you can have links to your helpdesk, for example (Fact Sheet Resources).
  4. Filter: Filter by Domain/Groups, in this case by Business Capabilities, as configured by the Admin.
  5. Fact Sheets: In this example, all Applications available in the Inventory are shown. Once a Filter or Search is applied, the results will be visible here.
  6. Reference panel: Provides quick access to reports and diagrams to authorized users.
  7. Action button: Perform an action, in this case "Request new Application" when not already available in the workspace. This link is also configurable.


**Note**
Resources uploaded to a fact sheet that are not links or images are not shown in portals.
When selecting one of the available Applications, the below pop-up appears, allowing you to see more information about the Application, and to request it.
![Application details pop-up with description, status, business capabilities, and tags.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioc95bb1d0a5d3491491d0d8bb45eafa77_HiRes.png)
Additional information includes Description, Status, Approval, Successors, Users, Tags, resources like Diagrams for authorized users, or even the internal experts on this Application, as configured in Subscriptions and Roles (Responsible/Accountable).
